@@ -2,14 +2,20 @@
 """
 | ----------------------------------------------------------------------------------------------------------------------
 | Date                : June 2018
-| Copyright           : (C) 2018 by Ann Crabbé (KU Leuven)
-| Email               : ann.crabbe@kuleuven.be
+| Copyright           : © 2018 - 2020 by Ann Crabbé (KU Leuven)
+| Email               : acrabbe.foss@gmail.com
 | Acknowledgements    : Translated from VIPER Tools 2.0 (UC Santa Barbara, VIPER Lab).
 |                       Dar Roberts, Kerry Halligan, Philip Dennison, Kenneth Dudley, Ben Somers, Ann Crabbé
 |
-| This program is free software; you can redistribute it and/or modify it under the terms of the GNU
-| General Public License as published by the Free Software Foundation; either version 3 of the
-| License, or any later version.
+| This file is part of the Spectral Libraries QGIS plugin and python package.
+|
+| This program is free software: you can redistribute it and/or modify it under the terms of the GNU General Public
+| License as published by the Free Software Foundation, either version 3 of the License, or any later version.
+|
+| This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied
+| warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.
+|
+| You should have received a copy of the GNU General Public License along with Foobar.  If not see www.gnu.org/licenses.
 | ----------------------------------------------------------------------------------------------------------------------
 """
 import os
