@@ -1,16 +1,22 @@
+# -*- coding: utf-8 -*-
 """
-docstring_ignore
---------------------------------------------------------
-Date                : March 2020
-Copyright           : (C) 2020 by Ann Crabbé (KU Leuven)
-Email               : ann.crabbe@kuleuven.be
-Acknowledgements    : Translated from VIPER Tools 2.0 (UC Santa Barbara, VIPER Lab)
-                      Dar Roberts, Kerry Halligan, Philip Dennison, Kenneth Dudley, Ben Somers, Ann Crabbé
-
-This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public
-License as published by the Free Software Foundation; either version 3 of the License, or any later version.
---------------------------------------------------------
-docstring_ignore
+| ----------------------------------------------------------------------------------------------------------------------
+| Date                : March 2020
+| Copyright           : © 2020 by Ann Crabbé (KU Leuven)
+| Email               : acrabbe.foss@gmail.com
+| Acknowledgements    : Translated from VIPER Tools 2.0 (UC Santa Barbara, VIPER Lab).
+|                       Dar Roberts, Kerry Halligan, Philip Dennison, Kenneth Dudley, Ben Somers, Ann Crabbé
+|
+| This file is part of the Spectral Libraries QGIS plugin and python package.
+|
+| This program is free software: you can redistribute it and/or modify it under the terms of the GNU General Public
+| License as published by the Free Software Foundation, either version 3 of the License, or any later version.
+|
+| This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied
+| warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.
+|
+| You should have received a copy of the GNU General Public License along with Foobar.  If not see www.gnu.org/licenses.
+| ----------------------------------------------------------------------------------------------------------------------
 """
 from os import path
 from weakref import WeakValueDictionary
@@ -46,7 +52,7 @@ class SpectralLibrariesPlugin:
         # List of actions added by this plugin
         self.actions = []
 
-        from .sitepackages.qps import initAll
+        from .externals.qps import initAll
         initAll()
 
         # Add an empty menu to the Raster Menu
